Name:           bloaty
Version:        1.1
Release:        %mkrel 17
Summary:        A size profiler for binaries
Group:          Development/Other
License:        ASL 2.0
URL:            https://github.com/google/bloaty
Source0:        https://github.com/google/bloaty/archive/v%{version}/%{name}-%{version}.tar.gz
# Patch to use system versions of abseil, google-test and google-mock
Patch0:         bloaty-1.1-absl.patch
# Patch to fix size detection function to use 64 bit types on 32bit architectures
Patch1:         bloaty-1.1-longlong.patch
# Add missing #include needed on GCC13
# https://github.com/google/bloaty/pull/332
Patch2:         %{url}/pull/332.patch

BuildRequires:  abseil-cpp-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig(capstone)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(re2)

%description
Ever wondered what's making your binary big? Bloaty McBloatface will show
you a size profile of the binary so you can understand what's taking up
space inside.

Bloaty works on binaries, shared objects, object files, and static
libraries. Bloaty supports the ELF and Mach-O formats, and has experimental
support for WebAssembly.

%prep
%autosetup -S gendiff -N
%autopatch -p0 -M 1
%autopatch -p1 -m 2

%build
%cmake \
  -DBUILD_SHARED_LIBS=OFF \
  -DBLOATY_ENABLE_CMAKETARGETS=OFF \
  -DBUILD_TESTING=ON
%cmake_build

%install
%cmake_install

%check
%ctest --verbose || exit 0

%files
%license LICENSE
%doc README.md how-bloaty-works.md
%{_bindir}/%{name}


%changelog
* Tue Mar 11 2025 daviddavid <daviddavid> 1.1-17.mga10
+ Revision: 2162662
- rebuild for new protobuf 30.0

* Sun Mar 09 2025 wally <wally> 1.1-16.mga10
+ Revision: 2162128
- rebuild for abseil-cpp 20250127.0

* Sun May 26 2024 cjw <cjw> 1.1-15.mga10
+ Revision: 2067847
- rebuild for abseil-cpp update

* Wed May 15 2024 daviddavid <daviddavid> 1.1-14.mga10
+ Revision: 2064253
- add fedora patch to fix build with GCC 13

* Mon Dec 11 2023 tv <tv> 1.1-13.mga10
+ Revision: 2017186
- Rebuild for capstone-5

* Sat Sep 23 2023 daviddavid <daviddavid> 1.1-12.mga10
+ Revision: 1989501
- fix build with absl needing minimum C++14
- rebuild for new abseil-cpp 20230802.0

* Thu Sep 07 2023 daviddavid <daviddavid> 1.1-11.mga10
+ Revision: 1984954
- rebuild for new re2 20230901

* Thu Dec 22 2022 wally <wally> 1.1-10.mga9
+ Revision: 1925778
- rebuild for protobuf 21.12

* Fri Sep 09 2022 akien <akien> 1.1-9.mga9
+ Revision: 1886129
- Rebuild for abseil-cpp 20220623.1

* Mon Aug 08 2022 wally <wally> 1.1-8.mga9
+ Revision: 1876260
- rebuild for abseil-cpp 20220623.0

* Fri Apr 01 2022 umeabot <umeabot> 1.1-7.mga9
+ Revision: 1838985
- Mageia 9 Mass Rebuild

* Wed Dec 29 2021 wally <wally> 1.1-6.mga9
+ Revision: 1765230
- rebuild for abseil-cpp 20211102.0

* Tue Dec 28 2021 wally <wally> 1.1-5.mga9
+ Revision: 1764964
- rebuild for protobuf 3.19.1

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1.1-4.mga8
+ Revision: 1660999
- rebuild for protobuf

* Thu Dec 03 2020 luigiwalser <luigiwalser> 1.1-3.mga8
+ Revision: 1652189
- rebuild for re2

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.1-2.mga8
+ Revision: 1650715
- rebuild for protobuf

* Wed Oct 14 2020 akien <akien> 1.1-1.mga8
+ Revision: 1635894
- import bloaty-1.1-5.fc34


* Wed Sep 23 2020 Adrian Reber <adrian@lisas.de> - 1.1-5
- Rebuilt for protobuf 3.13

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed May 27 2020 Rich Mattes <richmattes@gmail.com> - 1.1-2
- Don't remove buildroot in install
- Patch to use system gtest and gmock, enable tests

* Sat May 23 2020 Rich Mattes <richmattes@gmail.com> - 1.1-1
- Inital Package 
